## 1.7.1 (2021-12-17)

Always import Protocol from typing in stubs (#6617)

## 1.7.0 (2021-12-07)

toposort: Make argument types less restrictive (#6531)

## 1.6.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 1.6.0 (2021-09-19)

Create stubs for toposort (#6048)

